dojox.Grid with Dojo.Data via binding. Multiple Store implementations.

# dojox.Grid using Dojo.Data stores via simple binding with multiple store implementations.

This page demonstrates the Grid can display data accessed by dojo.data implementing Datastores. Each of the datastores used stores data in a different format, and as this test and demonstration page shows, the logic for rendering the data is virtually identical. You define your source store, you define the model for accessing the data, which is ij this case the dojox.grid.data.DojoData model and then you define the layout, which maps the data attribute names to columns in the grid. You can even perform cusomization of what is displayed, as demonstrated in the dojox.data.FlickrStore layout. The image url is displayed as a clickable link that opens a new page.

The choice of stores used were ones that did not require back end services to function for sake of simplicity. There is no reason that dojox.data.QueryReadStore could not be used with grid as well, it just requires a back end service to send it the query results.

Stores used:

- dojo.data.ItemFileReadStore
- dojox.data.CvsStore
- dojox.data.XmlStore
- dojox.data.FlickrStore
- dojox.data.OpmlStore
- dojox.data.HtmlTableStore

## dojo.data.ItemFileReadStore:

Displays a list of countries through ItemFileReadStore format.

## dojox.data.CsvStore:

Displays a list of movies that were stored in CSV format.

## dojox.data.XmlStore:

Displays a list of books that were stored in XML format.

## dojox.data.FlickrStore:

Displays Flickr imformation on 3DNY (Dojo Developer Days, New York) from the flickr public photo feed, accessed via the FlickrStore dojo.data implementation.

## dojox.data.OpmlStore:

Scans an Opml based document for all items of type 'country'

## dojox.data.HtmlStore:

Loads the grid from an HTML Table.

Column 1 | Column 2 | Column 3 | Column 4
--- | --- | --- | ---
This | is |  | empty in column 3
This | is | a | value
Who? | What? | When? | Where?
She | sells | sea | shells